#! /usr/bin/env python

# script utility to parse the source of the resonance wiki and return a version sorted by measured frequency column

import parsereswiki
import sys

if __name__=="__main__":
    if len(sys.argv)>=2 and sys.argv[1]=="-h":
        print("""sortbyfmeas.py is a Unix pipeline utility to read the source of the resonance wiki page from stdin and write a version sorted by the f_meas column to stdout. Any data rows with incorrect format will be printed to stderr.""")
    else:   
        
        rawtext = sys.stdin.readlines()
        
        (parseddata, baddata) = parsereswiki.dparse(rawtext)
        
        # if any bad data lines, print them so the user can debug them
        if len(baddata)<>0:
            sys.stderr.write("Bad data rows: "+str(len(baddata))+"\n")
            for l in baddata:
                sys.stderr.write(l)
                    
        fmeasorder = sorted(parseddata,key=parsereswiki.fmeas)
        
        withspaces = [[" " if c=="" else c for c in l] for l in fmeasorder]
        
        sys.stdout.write("= aLIGO LHO Resonances wiki data sorted by measured frequency =\n")
        sys.stdout.write("This page is generated by a python script. Please make edits to the [[../|main page above]] and then rerun `sortbyfmeas.py` as described on the [[../Scripts|scripts]] page.\n\n")
        sys.stdout.write("Unmeasured resonances have been treated as zero frequency, so measured frequencies sort to the end. Just scroll down.\n\n")

        sys.stdout.write("== Resonances ==\n")
        
        sys.stdout.write("||IFO||Group||Location||System||Subsystem||Description||f,,theory,, (Hz)||Q,,theory,,||f,,meas,, (Hz)||Q,,meas,,||Harmonic||\n")
        for l in withspaces:
             sys.stdout.write("||"+l[0]+"||"+l[1]+"||"+l[2]+"||"+l[3]+"||"+l[4]+"||"+l[5]+"||"+l[6]+"||"+l[7]+"||"+l[8]+"||"+l[9]+"||"+l[10]+"||\n")
             
        # Do references

        (parsedrefs, badrefs) = parsereswiki.rparse(rawtext)
        
        # if any bad refs lines, print them so the user can debug them
        if len(badrefs)<>0:
            sys.stderr.write("Bad reference rows: "+str(len(badrefs))+"\n")
            for l in badrefs:
                sys.stderr.write(l)
                            
        withspaces = [[" " if c=="" else c for c in l] for l in parsedrefs]
        
        sys.stdout.write("== References ==\n")
        for l in withspaces:
             sys.stdout.write("||"+l[0]+"||"+l[1]+"||\n")
